@@ -69,27 +69,14 @@ impl PartialEq<&str> for StateName {
 }
 
 impl State {
-    #[cfg(test)]
-    pub fn new(name: impl AsRef<str>) -> Self {
-        let name = StateName::from(name.as_ref());
-        Self {
-            id: Uuid::default(),
-            name,
-            created: Utc::now(),
-            modified: Utc::now(),
-            storage_class: None,
-            locations: StateLocations::default(),
-            owner: None,
-            provisioning_status: ProvisioningStatus::default(),
-            allowed_clusters: None,
-            condition: Condition::Green,
-        }
-    }
-
     pub fn is_available_in(&self, location: &Location) -> bool {
         self.locations.contains(location)
     }
 
+    pub fn is_ready(&self) -> bool {
+        self.condition == Condition::Green
+    }
+
     pub fn all_locations(&self) -> Vec<Location> {
         let aws = self.locations.aws.iter().map(|aws| aws.region.into());
         let azure = self.locations.azure.iter().map(|azure| azure.region.into());
